Powerbase: Los Angeles Event #2 Strategicon - GAMEX 2010, Los Angeles, California May 29th 2010 2R+F 15 players Darby Keeney Deck Name: Cholinesterase Inhibition - Last Call Comments: This is probably the last time I'll play this deck. I'll have to find another abuse for Art of Memory. Crypt (12 cards, min=19, max=32, avg=6.42) ------------------------------------------ 2x Persephone Tar-Anis 8 AUS DEM OBF cel pot Malkavian antitribu:4 2x White Lily 8 DEM OBF cel dom for Malkavian antitribu:4 2x Marge Khan 7 DEM OBF POT aus for Malkavian antitribu:5 2x Hagar Stone 6 AUS DEM obf Malkavian antitribu:5 1x Apache Jones 5 DEM aus for obf Malkavian antitribu:4 1x Gabriel de Cambrai 5 aus cel dem obf pre Toreador antitribu:4 1x Luc 5 OBF dem vic Malkavian antitribu:4 1x Beauregard Krueller 4 aus dem obf Malkavian antitribu:4 Library (71 cards) Master (7; 3 trifle) 1x Blood Doll 2x Direct Intervention 1x Sudden Reversal 3x Villein Action (16) 1x Black Hand Ritual -- To remove Anthelios and/or The Unmasking. 2x Call, The 9x Kindred Spirits 2x Madman's Quill 2x Reunion Kamut Action Modifier (35) 11x Art of Memory, The -- Linchpin card for dialing in the moment-appropriate card. 2x Cloak the Gathering 4x Confusion 3x Elder Impersonation 4x Eyes of Chaos 3x Faceless Night 3x Freak Drive 3x Lost in Crowds 2x Mask of a Thousand Faces Action Modifier/Combat (8) 3x Deny 2x Hide the Mind -- Generates 2-3VP per tournament in this deck. 3x Swallowed by the Night Action Modifier/Reaction (1) 1x Touch of Clarity -- Recent addition, unneeded in this tournament. Reaction (4) 2x On the Qui Vive 2x Telepathic Misdirection